@@ -15,6 +15,9 @@ G_BEGIN_DECLS
 #define E_EWS_CONNECTION_UTILS_CHECK_ELEMENT(element_name, expected_name) \
 	(e_ews_connection_utils_check_element (G_STRFUNC, (element_name), (expected_name)))
 
+void		e_ews_connection_utils_set_user_agent_header
+							(SoupMessage *message,
+							 CamelEwsSettings *settings);
 void		e_ews_connection_utils_unref_in_thread	(gpointer object);
 gboolean	e_ews_connection_utils_check_element	(const gchar *function_name,
 							 const gchar *element_name,
@@ -32,18 +35,6 @@ gboolean	e_ews_connection_utils_check_x_ms_credential_headers
 							 gint *out_expire_in_days,
 							 gboolean *out_expired,
 							 gchar **out_service_url);
-void		e_ews_connection_utils_prepare_auth_method
-							(SoupSession *soup_session,
-							 EwsAuthType auth_method);
-void		e_ews_connection_utils_authenticate	(EEwsConnection *cnc,
-							 SoupSession *session,
-							 SoupMessage *msg,
-							 SoupAuth *auth,
-							 gboolean retrying);
-gboolean	e_ews_connection_utils_prepare_message	(EEwsConnection *cnc,
-							 SoupSession *session,
-							 SoupMessage *message,
-							 GCancellable *cancellable);
 
 G_END_DECLS
 
