@@ -16,6 +16,8 @@ typedef enum {
 	E_M365_FOLDER_KIND_MAIL,
 	E_M365_FOLDER_KIND_CALENDAR,
 	E_M365_FOLDER_KIND_CONTACTS,
+	E_M365_FOLDER_KIND_ORG_CONTACTS,
+	E_M365_FOLDER_KIND_USERS,
 	E_M365_FOLDER_KIND_SEARCH,
 	E_M365_FOLDER_KIND_TASKS,
 	E_M365_FOLDER_KIND_MEMOS
