@@ -50,6 +50,7 @@ G_BEGIN_DECLS
 #define EM365WorkingHours		JsonObject
 
 #define E_M365_RECURRENCE_BLOB_NAME "Binary {00062002-0000-0000-c000-000000000046} Id 0x8216"
+#define E_M365_PT_MESSAGE_SIZE_NAME "Long 0xe08" /* PidTagMessageSize */
 
 typedef enum _EM365AttachmentDataType {
 	E_M365_ATTACHMENT_DATA_TYPE_NOT_SET,
@@ -303,6 +304,10 @@ void		e_m365_json_add_nonempty_or_null_string_member
 const gchar *	e_m365_json_get_string_single_value_extended_property
 							(JsonObject *object,
 							 const gchar *property_name);
+gint64		e_m365_json_get_integer_single_value_extended_property
+							(JsonObject *object,
+							 const gchar *property_name,
+							 gint64 default_value);
 
 EM365Date	e_m365_date_get				(JsonObject *object,
 							 const gchar *member_name);
